You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by da...@apache.org on 2005/12/13 07:26:29 UTC

svn commit: r356488 [3/8] - in /webservices/axis2/trunk/c: include/ modules/core/addr/src/ modules/core/context/src/ modules/core/deployment/src/ modules/core/description/src/ modules/core/engine/src/ modules/core/phaseresolver/src/ modules/core/transp...

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_feature.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_feature.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_feature.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_feature.h Mon Dec 12 22:23:36 2005
@@ -44,8 +44,8 @@
  */
 
 /** 
- * @brief Wsdl Feature operations struct
- * Encapsulator struct for operations of axis2_wsdl_feature
+ * @brief Wsdl Feature ops struct
+ * Encapsulator struct for ops of axis2_wsdl_feature
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_feature_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_interface.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_interface.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_interface.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_interface.h Mon Dec 12 22:23:36 2005
@@ -28,8 +28,8 @@
 #include <axis2_env.h>
 #include <axis2_allocator.h>
 #include <axis2_hash.h>
-#include <axis2_wsdl_operation.h>
-#include <axis2_operation.h>
+#include <axis2_wsdl_op.h>
+#include <axis2_op.h>
 #include <axis2_linked_list.h>
 #include <axis2_wsdl_extensible_component.h>
 
@@ -38,8 +38,8 @@
 {
 #endif
     
-struct axis2_wsdl_operation;
-struct axis2_operation;    
+struct axis2_wsdl_op;
+struct axis2_op;    
 struct axis2_wsdl_extensible_component;    
 typedef struct axis2_wsdl_interface axis2_wsdl_interface_t;
 typedef struct axis2_wsdl_interface_ops axis2_wsdl_interface_ops_t;
@@ -51,8 +51,8 @@
 
 
 /** 
- * @brief Wsdl Interface operations struct
- * Encapsulator struct for operations of axis2_wsdl_interface
+ * @brief Wsdl Interface ops struct
+ * Encapsulator struct for ops of axis2_wsdl_interface
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_interface_ops
 {
@@ -69,7 +69,7 @@
      * @return
      */
     axis2_hash_t *(AXIS2_CALL *
-    get_defined_operations) (axis2_wsdl_interface_t *wsdl_interface,
+    get_defined_ops) (axis2_wsdl_interface_t *wsdl_interface,
                                                 axis2_env_t **env);
     
     /**
@@ -90,7 +90,7 @@
      * @return
      */
     axis2_hash_t *(AXIS2_CALL *
-    get_operations) (axis2_wsdl_interface_t *wsdl_interface,
+    get_ops) (axis2_wsdl_interface_t *wsdl_interface,
                                         axis2_env_t **env);
     
     /**
@@ -100,7 +100,7 @@
      * @return
      */
     void *(AXIS2_CALL *
-    get_operation) (axis2_wsdl_interface_t *wsdl_interface,
+    get_op) (axis2_wsdl_interface_t *wsdl_interface,
                                     axis2_env_t **env,
                                     axis2_char_t *nc_name);
                                     
@@ -152,22 +152,22 @@
      * @param list
      */
     axis2_status_t (AXIS2_CALL *
-    set_operations) (axis2_wsdl_interface_t *wsdl_interface,
+    set_ops) (axis2_wsdl_interface_t *wsdl_interface,
                                         axis2_env_t **env,
                                         axis2_hash_t *list);
                                         
     /**
-     * The operation is added by its ncname. If operation is null
+     * The op is added by its ncname. If op is null
      * it will not be added. If the Operation name is null a
      * <code>WSDLProcessingException</code> will be thrown.
      *
-     * @param operation
+     * @param op
      */
     axis2_status_t (AXIS2_CALL *
-    set_operation) (axis2_wsdl_interface_t *wsdl_interface,
+    set_op) (axis2_wsdl_interface_t *wsdl_interface,
                                         axis2_env_t **env,
-                                        void *operation,
-                                        axis2_operation_type_t opt_type);
+                                        void *op,
+                                        axis2_op_type_t opt_type);
     
     /**
      * @param list
@@ -218,7 +218,7 @@
 {
 	axis2_wsdl_interface_ops_t *ops;
     struct axis2_wsdl_extensible_component *extensible_component;
-    axis2_operation_type_t optr_type; /*0-wsdl_operation, 1-axis2_operation */
+    axis2_op_type_t optr_type; /*0-wsdl_op, 1-axis2_op */
 };
 
 /**
@@ -233,7 +233,7 @@
 		((wsdl_interface->ops)->free (wsdl_interface, env))
 
 #define AXIS2_WSDL_INTERFACE_GET_DEFINED_OPERATIONS(wsdl_interface, env) \
-		((wsdl_interface->ops)->get_defined_operations (wsdl_interface, env))
+		((wsdl_interface->ops)->get_defined_ops (wsdl_interface, env))
 
 #define AXIS2_WSDL_INTERFACE_GET_FAULTS(wsdl_interface, env) \
 		((wsdl_interface->ops)->get_faults (wsdl_interface, env))
@@ -242,10 +242,10 @@
 		((wsdl_interface->ops)->get_name (wsdl_interface, env))
 
 #define AXIS2_WSDL_INTERFACE_GET_OPERATIONS(wsdl_interface, env) \
-		((wsdl_interface->ops)->get_operations (wsdl_interface, env))
+		((wsdl_interface->ops)->get_ops (wsdl_interface, env))
 
 #define AXIS2_WSDL_INTERFACE_GET_OPERATION(wsdl_interface, env, nc_name) \
-		((wsdl_interface->ops)->get_operation (wsdl_interface, env, nc_name))
+		((wsdl_interface->ops)->get_op (wsdl_interface, env, nc_name))
         
 #define AXIS2_WSDL_INTERFACE_GET_SUPER_INTERFACES(wsdl_interface, env) \
 		((wsdl_interface->ops)->get_super_interfaces (wsdl_interface, env))
@@ -263,10 +263,10 @@
 		((wsdl_interface->ops)->set_name (wsdl_interface, env, name))
         
 #define AXIS2_WSDL_INTERFACE_SET_OPERATIONS(wsdl_interface, env, list) \
-		((wsdl_interface->ops)->set_operations (wsdl_interface, env, list))
+		((wsdl_interface->ops)->set_ops (wsdl_interface, env, list))
 
-#define AXIS2_WSDL_INTERFACE_SET_OPERATION(wsdl_interface, env, operation, optr_type) \
-		((wsdl_interface->ops)->set_operation (wsdl_interface, env, operation, optr_type))
+#define AXIS2_WSDL_INTERFACE_SET_OPERATION(wsdl_interface, env, op, optr_type) \
+		((wsdl_interface->ops)->set_op (wsdl_interface, env, op, optr_type))
 
 #define AXIS2_WSDL_INTERFACE_SET_SUPER_INTERFACES(wsdl_interface, env, list) \
 		((wsdl_interface->ops)->set_super_interfaces (wsdl_interface, env, list))

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_msg_ref.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_msg_ref.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_msg_ref.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_msg_ref.h Mon Dec 12 22:23:36 2005
@@ -45,8 +45,8 @@
  */
 
 /** 
- * @brief Wsdl Binding Message Reference operations struct
- * Encapsulator struct for operations of axis2_wsdl_msg_ref
+ * @brief Wsdl Binding Message Reference ops struct
+ * Encapsulator struct for ops of axis2_wsdl_msg_ref
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_msg_ref_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_operation.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_operation.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_property.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_property.h Mon Dec 12 22:23:36 2005
@@ -44,8 +44,8 @@
  */
 
 /** 
- * @brief Wsdl Property operations struct
- * Encapsulator struct for operations of axis2_wsdl_property
+ * @brief Wsdl Property ops struct
+ * Encapsulator struct for ops of axis2_wsdl_property
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_property_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_soap_operation.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_soap_operation.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_svc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_svc.h Mon Dec 12 22:23:36 2005
@@ -54,8 +54,8 @@
 #define STYLE_DOC  "doc"
 #define STYLE_MSG  "msg"
 /** 
- * @brief Wsdl Service operations struct
- * Encapsulator struct for operations of axis2_wsdl_service
+ * @brief Wsdl Service ops struct
+ * Encapsulator struct for ops of axis2_wsdl_service
  */
 struct axis2_wsdl_svc_ops
 {

Modified: webservices/axis2/trunk/c/modules/core/addr/src/any_content_type.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/addr/src/any_content_type.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/addr/src/any_content_type.c (original)
+++ webservices/axis2/trunk/c/modules/core/addr/src/any_content_type.c Mon Dec 12 22:23:36 2005
@@ -61,7 +61,7 @@
         return NULL;        
     }
     
-    /* initialize operations */
+    /* initialize ops */
     any_content_type_impl->any_content_type.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_any_content_type_ops_t) );
     if (!any_content_type_impl->any_content_type.ops)
     {

Modified: webservices/axis2/trunk/c/modules/core/addr/src/endpoint_ref.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/addr/src/endpoint_ref.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/addr/src/endpoint_ref.c (original)
+++ webservices/axis2/trunk/c/modules/core/addr/src/endpoint_ref.c Mon Dec 12 22:23:36 2005
@@ -106,7 +106,7 @@
         }
     }
     
-    /* initialize operations */
+    /* initialize ops */
     endpoint_ref_impl->endpoint_ref.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_endpoint_ref_ops_t) );
     if (!endpoint_ref_impl->endpoint_ref.ops)
     {

Modified: webservices/axis2/trunk/c/modules/core/addr/src/msg_info_headers.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/addr/src/msg_info_headers.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/addr/src/msg_info_headers.c (original)
+++ webservices/axis2/trunk/c/modules/core/addr/src/msg_info_headers.c Mon Dec 12 22:23:36 2005
@@ -125,7 +125,7 @@
         }
     }
     
-    /* initialize operations */
+    /* initialize ops */
     msg_info_headers_impl->msg_info_headers.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_msg_info_headers_ops_t) );
     if (!msg_info_headers_impl->msg_info_headers.ops)
     {

Modified: webservices/axis2/trunk/c/modules/core/addr/src/relates_to.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/addr/src/relates_to.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/addr/src/relates_to.c (original)
+++ webservices/axis2/trunk/c/modules/core/addr/src/relates_to.c Mon Dec 12 22:23:36 2005
@@ -77,7 +77,7 @@
         }
     }
 
-    /* initialize operations */
+    /* initialize ops */
     relates_to_impl->relates_to.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_relates_to_ops_t) );
     if (!relates_to_impl->relates_to.ops)
     {

Modified: webservices/axis2/trunk/c/modules/core/addr/src/svc_name.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/addr/src/svc_name.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/addr/src/svc_name.c (original)
+++ webservices/axis2/trunk/c/modules/core/addr/src/svc_name.c Mon Dec 12 22:23:36 2005
@@ -81,7 +81,7 @@
         }
     }
 
-    /* initialize operations */
+    /* initialize ops */
     svc_name_impl->svc_name.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_svc_name_ops_t) );
     if (!svc_name_impl->svc_name.ops)
     {

Modified: webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c Mon Dec 12 22:23:36 2005
@@ -32,7 +32,7 @@
      * axis2_hash_t *containing <code>MessageID</code> to
      * <code>OperationContext</code> mapping.
      */
-    axis2_hash_t *operation_ctx_map;
+    axis2_hash_t *op_ctx_map;
 
     axis2_hash_t *svc_ctx_map;
 
@@ -49,17 +49,17 @@
     axis2_env_t **env);
 axis2_engine_config_t* AXIS2_CALL axis2_conf_ctx_get_engine_config(struct axis2_conf_ctx *conf_ctx, 
     axis2_env_t **env);
-axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_operation_ctx_map(struct axis2_conf_ctx *conf_ctx, 
+axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_op_ctx_map(struct axis2_conf_ctx *conf_ctx, 
     axis2_env_t **env);
 axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_svc_ctx_map(struct axis2_conf_ctx *conf_ctx, 
     axis2_env_t **env);
 axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_svc_grp_ctx_map(struct axis2_conf_ctx *conf_ctx, 
                                                             axis2_env_t **env);
-axis2_status_t AXIS2_CALL axis2_conf_ctx_register_operation_ctx(struct axis2_conf_ctx *conf_ctx, 
+axis2_status_t AXIS2_CALL axis2_conf_ctx_register_op_ctx(struct axis2_conf_ctx *conf_ctx, 
                                                                 axis2_env_t **env,
                                                                 axis2_char_t *message_id,
-                                                                axis2_operation_ctx_t *operation_ctx);
-axis2_operation_ctx_t* AXIS2_CALL axis2_conf_ctx_get_operation_ctx(struct axis2_conf_ctx *conf_ctx, 
+                                                                axis2_op_ctx_t *op_ctx);
+axis2_op_ctx_t* AXIS2_CALL axis2_conf_ctx_get_op_ctx(struct axis2_conf_ctx *conf_ctx, 
                                                                         axis2_env_t **env,
                                                                         axis2_char_t *message_id);
 axis2_status_t AXIS2_CALL axis2_conf_ctx_register_svc_ctx(struct axis2_conf_ctx *conf_ctx, 
@@ -108,7 +108,7 @@
     conf_ctx_impl->base = NULL;
     conf_ctx_impl->engine_config = NULL;
     conf_ctx_impl->root_dir = NULL;
-    conf_ctx_impl->operation_ctx_map = NULL;
+    conf_ctx_impl->op_ctx_map = NULL;
     conf_ctx_impl->svc_ctx_map = NULL;
     conf_ctx_impl->svc_grp_ctx_map = NULL;
     
@@ -122,8 +122,8 @@
         return NULL;
     }
     
-    conf_ctx_impl->operation_ctx_map = axis2_hash_make(env);
-    if (!(conf_ctx_impl->operation_ctx_map))
+    conf_ctx_impl->op_ctx_map = axis2_hash_make(env);
+    if (!(conf_ctx_impl->op_ctx_map))
     {
         axis2_conf_ctx_free(&(conf_ctx_impl->conf_ctx), env);
         return NULL;
@@ -143,7 +143,7 @@
         return NULL;
     }
     
-    /* initialize operations */    
+    /* initialize ops */    
     conf_ctx_impl->conf_ctx.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_conf_ctx_ops_t) );
     if (!conf_ctx_impl->conf_ctx.ops)
     {
@@ -157,11 +157,11 @@
     conf_ctx_impl->conf_ctx.ops->set_engine_config = axis2_conf_ctx_set_engine_config;
     conf_ctx_impl->conf_ctx.ops->get_base = axis2_conf_ctx_get_base;
     conf_ctx_impl->conf_ctx.ops->get_engine_config = axis2_conf_ctx_get_engine_config;
-    conf_ctx_impl->conf_ctx.ops->get_operation_ctx_map = axis2_conf_ctx_get_operation_ctx_map;
+    conf_ctx_impl->conf_ctx.ops->get_op_ctx_map = axis2_conf_ctx_get_op_ctx_map;
     conf_ctx_impl->conf_ctx.ops->get_svc_ctx_map = axis2_conf_ctx_get_svc_ctx_map;
     conf_ctx_impl->conf_ctx.ops->get_svc_grp_ctx_map = axis2_conf_ctx_get_svc_grp_ctx_map;
-    conf_ctx_impl->conf_ctx.ops->register_operation_ctx = axis2_conf_ctx_register_operation_ctx;
-    conf_ctx_impl->conf_ctx.ops->get_operation_ctx = axis2_conf_ctx_get_operation_ctx;
+    conf_ctx_impl->conf_ctx.ops->register_op_ctx = axis2_conf_ctx_register_op_ctx;
+    conf_ctx_impl->conf_ctx.ops->get_op_ctx = axis2_conf_ctx_get_op_ctx;
     conf_ctx_impl->conf_ctx.ops->register_svc_ctx = axis2_conf_ctx_register_svc_ctx;
     conf_ctx_impl->conf_ctx.ops->get_svc_ctx = axis2_conf_ctx_get_svc_ctx;
     conf_ctx_impl->conf_ctx.ops->register_svc_grp_ctx = axis2_conf_ctx_register_svc_grp_ctx;
@@ -201,10 +201,10 @@
     return AXIS2_INTF_TO_IMPL(conf_ctx)->engine_config;
 }
 
-axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_operation_ctx_map(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env)
+axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_op_ctx_map(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(conf_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(conf_ctx)->operation_ctx_map;
+    return AXIS2_INTF_TO_IMPL(conf_ctx)->op_ctx_map;
 }
 
 axis2_hash_t* AXIS2_CALL axis2_conf_ctx_get_svc_ctx_map(struct axis2_conf_ctx *conf_ctx, axis2_env_t **env)
@@ -221,15 +221,15 @@
 }
 
 /**
- * Register a struct axis2_operation_ctx against a given Message ID.
+ * Register a struct axis2_op_ctx against a given Message ID.
  *
  * @param messageID
  * @param mepContext
  */
-axis2_status_t AXIS2_CALL axis2_conf_ctx_register_operation_ctx(struct axis2_conf_ctx *conf_ctx, 
+axis2_status_t AXIS2_CALL axis2_conf_ctx_register_op_ctx(struct axis2_conf_ctx *conf_ctx, 
                                                                 axis2_env_t **env,
                                                                 axis2_char_t *message_id,
-                                                                axis2_operation_ctx_t *operation_ctx) 
+                                                                axis2_op_ctx_t *op_ctx) 
 {
     axis2_conf_ctx_impl_t *conf_ctx_impl = NULL;
     
@@ -237,21 +237,21 @@
     
     conf_ctx_impl = AXIS2_INTF_TO_IMPL(conf_ctx);
     
-    if (conf_ctx_impl->operation_ctx_map)
+    if (conf_ctx_impl->op_ctx_map)
     {
-        axis2_hash_set(conf_ctx_impl->operation_ctx_map, message_id, AXIS2_HASH_KEY_STRING, operation_ctx);
+        axis2_hash_set(conf_ctx_impl->op_ctx_map, message_id, AXIS2_HASH_KEY_STRING, op_ctx);
     }
     
     return AXIS2_SUCCESS;
 }
 
 /**
- * get axis2_operation_ctx struct given a Message ID
+ * get axis2_op_ctx struct given a Message ID
  *
  * @param message_id
- * @return struct axis2_operation_ctx * <code>struct axis2_operation_ctx *<code>
+ * @return struct axis2_op_ctx * <code>struct axis2_op_ctx *<code>
  */
-axis2_operation_ctx_t* AXIS2_CALL axis2_conf_ctx_get_operation_ctx(struct axis2_conf_ctx *conf_ctx, 
+axis2_op_ctx_t* AXIS2_CALL axis2_conf_ctx_get_op_ctx(struct axis2_conf_ctx *conf_ctx, 
                                                                         axis2_env_t **env,
                                                                         axis2_char_t *message_id) 
 {
@@ -261,9 +261,9 @@
     
     conf_ctx_impl = AXIS2_INTF_TO_IMPL(conf_ctx);
     
-    if (conf_ctx_impl->operation_ctx_map)
+    if (conf_ctx_impl->op_ctx_map)
     {
-        return (axis2_operation_ctx_t*)axis2_hash_get(conf_ctx_impl->operation_ctx_map, message_id, AXIS2_HASH_KEY_STRING);
+        return (axis2_op_ctx_t*)axis2_hash_get(conf_ctx_impl->op_ctx_map, message_id, AXIS2_HASH_KEY_STRING);
     }
     return NULL;
 }
@@ -423,14 +423,14 @@
 
     conf_ctx_impl->engine_config = engine_config;
     
-    for (hi = axis2_hash_first (conf_ctx_impl->operation_ctx_map, env);
+    for (hi = axis2_hash_first (conf_ctx_impl->op_ctx_map, env);
              hi; hi = axis2_hash_next (env, hi))
     {
         axis2_hash_this (hi, NULL, NULL, &ctx);
         if (ctx)
         {
-            axis2_operation_ctx_t *operation_ctx = (axis2_operation_ctx_t*) ctx;
-            AXIS2_OPERATION_CTX_INIT(operation_ctx, env, engine_config);
+            axis2_op_ctx_t *op_ctx = (axis2_op_ctx_t*) ctx;
+            AXIS2_OPERATION_CTX_INIT(op_ctx, env, engine_config);
         }
     }
 
@@ -474,10 +474,10 @@
         conf_ctx_impl->conf_ctx.ops = NULL;
     }
     
-    if (conf_ctx_impl->operation_ctx_map)
+    if (conf_ctx_impl->op_ctx_map)
     {
-        axis2_hash_free(conf_ctx_impl->operation_ctx_map, env);
-        conf_ctx_impl->operation_ctx_map = NULL;
+        axis2_hash_free(conf_ctx_impl->op_ctx_map, env);
+        conf_ctx_impl->op_ctx_map = NULL;
     }    
     
     if (conf_ctx_impl->svc_ctx_map)
@@ -521,7 +521,7 @@
     axis2_svc_t *svc = NULL;
     axis2_qname_t *qname = NULL;
     axis2_char_t *svc_id = NULL;
-    axis2_operation_ctx_t *operation_ctx = NULL;
+    axis2_op_ctx_t *op_ctx = NULL;
 
     
     AXIS2_FUNC_PARAM_CHECK(conf_ctx, env, NULL);
@@ -594,15 +594,15 @@
         axis2_conf_ctx_register_svc_grp_ctx(conf_ctx, env, svc_grp_ctx_id, svc_grp_ctx);        
     }
     
-    /* when you come here operation context MUST already been assigned to the message context */
-    operation_ctx = AXIS2_MSG_CTX_GET_OPERATION_CTX(msg_ctx, env);
-    if (!operation_ctx)
+    /* when you come here op context MUST already been assigned to the message context */
+    op_ctx = AXIS2_MSG_CTX_GET_OPERATION_CTX(msg_ctx, env);
+    if (!op_ctx)
     {
         AXIS2_ERROR_SET((*env)->error, AXIS2_ERROR_INVALID_STATE_MSG_CTX, AXIS2_FAILURE);
         return NULL;
     }
     
-    AXIS2_OPERATION_CTX_SET_PARENT(operation_ctx, env, svc_ctx);
+    AXIS2_OPERATION_CTX_SET_PARENT(op_ctx, env, svc_ctx);
     AXIS2_MSG_CTX_SET_SVC_CTX(msg_ctx, env, svc_ctx);
     AXIS2_MSG_CTX_SET_SVC_GRP_CTX(msg_ctx, env, svc_grp_ctx);
     return svc_grp_ctx;

Modified: webservices/axis2/trunk/c/modules/core/context/src/ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/ctx.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/ctx.c Mon Dec 12 22:23:36 2005
@@ -69,7 +69,7 @@
         return NULL;
     }
 	
-    /* initialize operations */
+    /* initialize ops */
     ctx_impl->ctx.ops = NULL;
     ctx_impl->ctx.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_ctx_ops_t) );
     if (!ctx_impl->ctx.ops)

Modified: webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c Mon Dec 12 22:23:36 2005
@@ -14,211 +14,211 @@
  * limitations under the License.
  */
 
-#include <axis2_operation_ctx.h>
+#include <axis2_op_ctx.h>
 #include <axis2.h>
 #include <axis2_hash.h>
 
-typedef struct axis2_operation_ctx_impl
+typedef struct axis2_op_ctx_impl
 {
     /** context base struct */
-    axis2_operation_ctx_t operation_ctx;
+    axis2_op_ctx_t op_ctx;
     /** base context struct */
     axis2_ctx_t *base;
-    /** parent of operation context is a service context instance */
+    /** parent of op context is a service context instance */
     struct axis2_svc_ctx *parent;
     /** message context map */
     axis2_hash_t *msg_ctx_map;
-    /** the operation of which this is a running instance. The MEP of this
-     * operation must be one of the 8 predefined ones in WSDL 2.0.
+    /** the op of which this is a running instance. The MEP of this
+     * op must be one of the 8 predefined ones in WSDL 2.0.
      */
-    axis2_operation_t *operation;
-    /** operation Message Exchange Pattern */
-    int operation_mep;
+    axis2_op_t *op;
+    /** op Message Exchange Pattern */
+    int op_mep;
     /** is complete? */
     axis2_bool_t is_complete;
-    /** the global message_id -> operation_ctx map which is stored in
+    /** the global message_id -> op_ctx map which is stored in
      * the axis2_conf_ctx. We're caching it here for faster acccess.
      */
-    axis2_hash_t *operation_ctx_map;
-    /** operation qname */
-    axis2_qname_t *operation_qname;
+    axis2_hash_t *op_ctx_map;
+    /** op qname */
+    axis2_qname_t *op_qname;
     /** service qname */
     axis2_qname_t *svc_qname;
-} axis2_operation_ctx_impl_t;
+} axis2_op_ctx_impl_t;
 
 /** Interface to implementation conversion macro */
-#define AXIS2_INTF_TO_IMPL(operation_ctx) ((axis2_operation_ctx_impl_t *)operation_ctx)
+#define AXIS2_INTF_TO_IMPL(op_ctx) ((axis2_op_ctx_impl_t *)op_ctx)
 
-axis2_ctx_t* AXIS2_CALL axis2_operation_ctx_get_base(struct axis2_operation_ctx *operation_ctx, 
+axis2_ctx_t* AXIS2_CALL axis2_op_ctx_get_base(struct axis2_op_ctx *op_ctx, 
                                             axis2_env_t **env);
-axis2_status_t AXIS2_CALL axis2_operation_ctx_free (struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_free (struct axis2_op_ctx *op_ctx, 
                                    axis2_env_t **env);
-axis2_status_t AXIS2_CALL axis2_operation_ctx_init(struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_init(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, 
     struct axis2_engine_config *engine_config);
-axis2_operation_t* AXIS2_CALL axis2_operation_ctx_getAxisOperation(struct axis2_operation_ctx *operation_ctx, 
+axis2_op_t* AXIS2_CALL axis2_op_ctx_getAxisOperation(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env);
-struct axis2_svc_ctx * AXIS2_CALL axis2_operation_ctx_get_parent(struct axis2_operation_ctx *operation_ctx, 
+struct axis2_svc_ctx * AXIS2_CALL axis2_op_ctx_get_parent(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env);
-axis2_status_t AXIS2_CALL axis2_operation_ctx_add_msg_ctx(struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_add_msg_ctx(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, 
     axis2_msg_ctx_t *msg_ctx);
-axis2_msg_ctx_t* AXIS2_CALL axis2_operation_ctx_get_msg_ctx(struct axis2_operation_ctx *operation_ctx, 
+axis2_msg_ctx_t* AXIS2_CALL axis2_op_ctx_get_msg_ctx(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, axis2_char_t *messageLabel);
-axis2_bool_t AXIS2_CALL axis2_operation_ctx_get_is_complete(struct axis2_operation_ctx *operation_ctx, 
+axis2_bool_t AXIS2_CALL axis2_op_ctx_get_is_complete(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env);
-axis2_status_t AXIS2_CALL axis2_operation_ctx_set_complete(struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_set_complete(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, 
     axis2_bool_t is_complete);
-axis2_status_t AXIS2_CALL axis2_operation_ctx_cleanup(struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_cleanup(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env);
-axis2_status_t AXIS2_CALL axis2_operation_ctx_set_parent(struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_set_parent(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, 
     struct axis2_svc_ctx* svc_ctx);
-axis2_operation_t* AXIS2_CALL axis2_operation_ctx_get_operation(struct axis2_operation_ctx *operation_ctx, 
+axis2_op_t* AXIS2_CALL axis2_op_ctx_get_op(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env);
-axis2_hash_t* AXIS2_CALL axis2_operation_ctx_get_msg_ctx_map(struct axis2_operation_ctx *operation_ctx, 
+axis2_hash_t* AXIS2_CALL axis2_op_ctx_get_msg_ctx_map(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env);
 
-axis2_operation_ctx_t* AXIS2_CALL axis2_operation_ctx_create(axis2_env_t **env, 
-    axis2_operation_t *operation,
+axis2_op_ctx_t* AXIS2_CALL axis2_op_ctx_create(axis2_env_t **env, 
+    axis2_op_t *op,
     struct axis2_svc_ctx* svc_ctx) 
 {
-    axis2_operation_ctx_impl_t *operation_ctx_impl = NULL;
+    axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     
     AXIS2_ENV_CHECK(env, NULL);
     
-    operation_ctx_impl = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_operation_ctx_impl_t) );
-    if (!operation_ctx_impl)
+    op_ctx_impl = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_op_ctx_impl_t) );
+    if (!op_ctx_impl)
     { 
         AXIS2_ERROR_SET((*env)->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
         return NULL;        
     }
 
-    operation_ctx_impl->operation_ctx.ops = NULL;
-    operation_ctx_impl->base = NULL;
-    operation_ctx_impl->parent = NULL;
-    operation_ctx_impl->msg_ctx_map = NULL;
-    operation_ctx_impl->operation = NULL;
-    operation_ctx_impl->operation_mep = 0;
-    operation_ctx_impl->is_complete = AXIS2_FALSE;
-    operation_ctx_impl->operation_ctx_map = NULL;
-    operation_ctx_impl->operation_qname = NULL;
-    operation_ctx_impl->svc_qname = NULL;
+    op_ctx_impl->op_ctx.ops = NULL;
+    op_ctx_impl->base = NULL;
+    op_ctx_impl->parent = NULL;
+    op_ctx_impl->msg_ctx_map = NULL;
+    op_ctx_impl->op = NULL;
+    op_ctx_impl->op_mep = 0;
+    op_ctx_impl->is_complete = AXIS2_FALSE;
+    op_ctx_impl->op_ctx_map = NULL;
+    op_ctx_impl->op_qname = NULL;
+    op_ctx_impl->svc_qname = NULL;
     
-    operation_ctx_impl->base = axis2_ctx_create(env);
-    if (!(operation_ctx_impl->base))
+    op_ctx_impl->base = axis2_ctx_create(env);
+    if (!(op_ctx_impl->base))
     {
-        axis2_operation_ctx_free(&(operation_ctx_impl->operation_ctx), env);
+        axis2_op_ctx_free(&(op_ctx_impl->op_ctx), env);
         return NULL;
     }
     
-    if (operation)
+    if (op)
     {
-        operation_ctx_impl->operation = operation;
+        op_ctx_impl->op = op;
     }
     
     
-    operation_ctx_impl->msg_ctx_map = axis2_hash_make(env);
-    if (!(operation_ctx_impl->msg_ctx_map))
+    op_ctx_impl->msg_ctx_map = axis2_hash_make(env);
+    if (!(op_ctx_impl->msg_ctx_map))
     {
-        axis2_operation_ctx_free(&(operation_ctx_impl->operation_ctx), env);
+        axis2_op_ctx_free(&(op_ctx_impl->op_ctx), env);
         return NULL;
     }
     
-    if (operation_ctx_impl->operation)
+    if (op_ctx_impl->op)
     {
-        /*operation_ctx_impl->operation_qname = AXIS2_OPERATION_GET_QNAME(operation_ctx_impl->operation, env);
-        operation_ctx_impl->operation_mep = AXIS2_OPERATION_GET_MEP_CONST(operation_ctx_impl->operation, env);*/
+        /*op_ctx_impl->op_qname = AXIS2_OPERATION_GET_QNAME(op_ctx_impl->op, env);
+        op_ctx_impl->op_mep = AXIS2_OPERATION_GET_MEP_CONST(op_ctx_impl->op, env);*/
     }
     
-    axis2_operation_ctx_set_parent(&(operation_ctx_impl->operation_ctx), env, svc_ctx);
+    axis2_op_ctx_set_parent(&(op_ctx_impl->op_ctx), env, svc_ctx);
     
-    /* initialize operations */    
-    operation_ctx_impl->operation_ctx.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_operation_ctx_ops_t) );
-    if (!operation_ctx_impl->operation_ctx.ops)
+    /* initialize ops */    
+    op_ctx_impl->op_ctx.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_op_ctx_ops_t) );
+    if (!op_ctx_impl->op_ctx.ops)
     {
         AXIS2_ERROR_SET((*env)->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
-        axis2_operation_ctx_free(&(operation_ctx_impl->operation_ctx), env);
+        axis2_op_ctx_free(&(op_ctx_impl->op_ctx), env);
         return NULL;        
     }
 
-    operation_ctx_impl->operation_ctx.ops->get_base = axis2_operation_ctx_get_base;
-    operation_ctx_impl->operation_ctx.ops->free = axis2_operation_ctx_free;
-    operation_ctx_impl->operation_ctx.ops->init = axis2_operation_ctx_init;
-    operation_ctx_impl->operation_ctx.ops->get_operation = axis2_operation_ctx_get_operation;
-    operation_ctx_impl->operation_ctx.ops->get_parent = axis2_operation_ctx_get_parent;
-    operation_ctx_impl->operation_ctx.ops->add_msg_ctx = axis2_operation_ctx_add_msg_ctx;
-    operation_ctx_impl->operation_ctx.ops->get_msg_ctx = axis2_operation_ctx_get_msg_ctx;
-    operation_ctx_impl->operation_ctx.ops->get_is_complete = axis2_operation_ctx_get_is_complete;
-    operation_ctx_impl->operation_ctx.ops->set_complete = axis2_operation_ctx_set_complete;
-    operation_ctx_impl->operation_ctx.ops->cleanup = axis2_operation_ctx_cleanup;
-    operation_ctx_impl->operation_ctx.ops->set_parent = axis2_operation_ctx_set_parent;
-    operation_ctx_impl->operation_ctx.ops->get_msg_ctx_map = axis2_operation_ctx_get_msg_ctx_map;
+    op_ctx_impl->op_ctx.ops->get_base = axis2_op_ctx_get_base;
+    op_ctx_impl->op_ctx.ops->free = axis2_op_ctx_free;
+    op_ctx_impl->op_ctx.ops->init = axis2_op_ctx_init;
+    op_ctx_impl->op_ctx.ops->get_op = axis2_op_ctx_get_op;
+    op_ctx_impl->op_ctx.ops->get_parent = axis2_op_ctx_get_parent;
+    op_ctx_impl->op_ctx.ops->add_msg_ctx = axis2_op_ctx_add_msg_ctx;
+    op_ctx_impl->op_ctx.ops->get_msg_ctx = axis2_op_ctx_get_msg_ctx;
+    op_ctx_impl->op_ctx.ops->get_is_complete = axis2_op_ctx_get_is_complete;
+    op_ctx_impl->op_ctx.ops->set_complete = axis2_op_ctx_set_complete;
+    op_ctx_impl->op_ctx.ops->cleanup = axis2_op_ctx_cleanup;
+    op_ctx_impl->op_ctx.ops->set_parent = axis2_op_ctx_set_parent;
+    op_ctx_impl->op_ctx.ops->get_msg_ctx_map = axis2_op_ctx_get_msg_ctx_map;
 
-    return &(operation_ctx_impl->operation_ctx);
+    return &(op_ctx_impl->op_ctx);
 }
 
-axis2_ctx_t* AXIS2_CALL axis2_operation_ctx_get_base(struct axis2_operation_ctx *operation_ctx, 
+axis2_ctx_t* AXIS2_CALL axis2_op_ctx_get_base(struct axis2_op_ctx *op_ctx, 
                                             axis2_env_t **env)
 {
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(operation_ctx)->base;
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, NULL);
+    return AXIS2_INTF_TO_IMPL(op_ctx)->base;
 }
 
 
-axis2_status_t AXIS2_CALL axis2_operation_ctx_free (struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_free (struct axis2_op_ctx *op_ctx, 
                                    axis2_env_t **env)
 {
-    axis2_operation_ctx_impl_t *operation_ctx_impl = NULL;
+    axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, AXIS2_FAILURE);
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, AXIS2_FAILURE);
     
-    operation_ctx_impl = AXIS2_INTF_TO_IMPL(operation_ctx);
+    op_ctx_impl = AXIS2_INTF_TO_IMPL(op_ctx);
     
-    if (operation_ctx_impl->operation_ctx.ops)
+    if (op_ctx_impl->op_ctx.ops)
     {
-        AXIS2_FREE((*env)->allocator, operation_ctx_impl->operation_ctx.ops);
-        operation_ctx_impl->operation_ctx.ops = NULL;
+        AXIS2_FREE((*env)->allocator, op_ctx_impl->op_ctx.ops);
+        op_ctx_impl->op_ctx.ops = NULL;
     }
     
-    if (operation_ctx_impl->base)
+    if (op_ctx_impl->base)
     {
-        AXIS2_CTX_FREE(operation_ctx_impl->base, env);
-        operation_ctx_impl->base = NULL;
+        AXIS2_CTX_FREE(op_ctx_impl->base, env);
+        op_ctx_impl->base = NULL;
     }
     
-    if (operation_ctx_impl->msg_ctx_map)
+    if (op_ctx_impl->msg_ctx_map)
     {
-        axis2_hash_free(operation_ctx_impl->msg_ctx_map, env);
-        operation_ctx_impl->msg_ctx_map = NULL;
+        axis2_hash_free(op_ctx_impl->msg_ctx_map, env);
+        op_ctx_impl->msg_ctx_map = NULL;
     }    
     
-    AXIS2_FREE((*env)->allocator, operation_ctx_impl);
-    operation_ctx_impl = NULL;
+    AXIS2_FREE((*env)->allocator, op_ctx_impl);
+    op_ctx_impl = NULL;
     
     return AXIS2_SUCCESS;
 }
 
 /**
- * The method is used to do the intialization of the axis2_operation_ctx
+ * The method is used to do the intialization of the axis2_op_ctx
  */
-axis2_status_t AXIS2_CALL axis2_operation_ctx_init(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env, struct axis2_engine_config *engine_config)
+axis2_status_t AXIS2_CALL axis2_op_ctx_init(struct axis2_op_ctx *op_ctx, axis2_env_t **env, struct axis2_engine_config *engine_config)
 {
-    axis2_operation_ctx_impl_t *operation_ctx_impl = NULL;
+    axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     axis2_hash_index_t *hi = NULL;
     void *ctx = NULL;
     
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, AXIS2_FAILURE);
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, AXIS2_FAILURE);
     
-    operation_ctx_impl = AXIS2_INTF_TO_IMPL(operation_ctx);
+    op_ctx_impl = AXIS2_INTF_TO_IMPL(op_ctx);
     
-    if (operation_ctx_impl->operation_qname && operation_ctx_impl->svc_qname)
+    if (op_ctx_impl->op_qname && op_ctx_impl->svc_qname)
     {
         axis2_svc_t *svc = NULL;
         axis2_char_t *svc_name = NULL;
         
-        svc_name = AXIS2_QNAME_GET_LOCALPART(operation_ctx_impl->svc_qname, env);
+        svc_name = AXIS2_QNAME_GET_LOCALPART(op_ctx_impl->svc_qname, env);
         
         if (svc_name)
         {
@@ -226,15 +226,15 @@
             
             if (svc)
             {
-               /* operation_ctx_impl->operation = AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc, env, operation_ctx_impl->operation_qname);*/
+               /* op_ctx_impl->op = AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc, env, op_ctx_impl->op_qname);*/
             }
         }
     }
 
-    if (!(operation_ctx_impl->msg_ctx_map))
+    if (!(op_ctx_impl->msg_ctx_map))
         return AXIS2_SUCCESS;
     
-    for (hi = axis2_hash_first (operation_ctx_impl->msg_ctx_map, env);
+    for (hi = axis2_hash_first (op_ctx_impl->msg_ctx_map, env);
              hi; hi = axis2_hash_next (env, hi))
     {
         axis2_hash_this (hi, NULL, NULL, &ctx);
@@ -249,23 +249,23 @@
 }
 
 /**
- * @return Returns the operation.
+ * @return Returns the op.
  */
-axis2_operation_t* AXIS2_CALL axis2_operation_ctx_get_operation(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env) 
+axis2_op_t* AXIS2_CALL axis2_op_ctx_get_op(struct axis2_op_ctx *op_ctx, axis2_env_t **env) 
 {
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(operation_ctx)->operation;
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, NULL);
+    return AXIS2_INTF_TO_IMPL(op_ctx)->op;
 }
 
 /**
- * Return the struct axis2_svc_ctx * in which this operation_ctx lives.
+ * Return the struct axis2_svc_ctx * in which this op_ctx lives.
  *
  * @return parent struct axis2_svc_ctx *
  */
-struct axis2_svc_ctx * AXIS2_CALL axis2_operation_ctx_get_parent(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env) 
+struct axis2_svc_ctx * AXIS2_CALL axis2_op_ctx_get_parent(struct axis2_op_ctx *op_ctx, axis2_env_t **env) 
 {
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(operation_ctx)->parent;
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, NULL);
+    return AXIS2_INTF_TO_IMPL(op_ctx)->parent;
 }
 
 /**
@@ -276,18 +276,18 @@
  *
  * @param msgContext
  */
-axis2_status_t AXIS2_CALL axis2_operation_ctx_add_msg_ctx(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env, axis2_msg_ctx_t *msg_ctx)  
+axis2_status_t AXIS2_CALL axis2_op_ctx_add_msg_ctx(struct axis2_op_ctx *op_ctx, axis2_env_t **env, axis2_msg_ctx_t *msg_ctx)  
 {
-    axis2_operation_ctx_impl_t *operation_ctx_impl = NULL;
+    axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, AXIS2_FAILURE);
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, AXIS2_FAILURE);
     
-    operation_ctx_impl = AXIS2_INTF_TO_IMPL(operation_ctx);
+    op_ctx_impl = AXIS2_INTF_TO_IMPL(op_ctx);
     
         
-    if(operation_ctx_impl->operation)
+    if(op_ctx_impl->op)
     {
-        /*return AXIS2_OPERATION_ADD_MSG_CTX(operation_ctx_impl->operation, env, msg_ctx, operation_ctx);*/
+        /*return AXIS2_OPERATION_ADD_MSG_CTX(op_ctx_impl->op, env, msg_ctx, op_ctx);*/
     }
     
     return AXIS2_SUCCESS;
@@ -299,18 +299,18 @@
  * @
  */
 
-axis2_msg_ctx_t* AXIS2_CALL axis2_operation_ctx_get_msg_ctx(struct axis2_operation_ctx *operation_ctx, 
+axis2_msg_ctx_t* AXIS2_CALL axis2_op_ctx_get_msg_ctx(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, axis2_char_t *message_id)
 {
-    axis2_operation_ctx_impl_t *operation_ctx_impl = NULL;
+    axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, NULL);
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, NULL);
     
-    operation_ctx_impl = AXIS2_INTF_TO_IMPL(operation_ctx);
+    op_ctx_impl = AXIS2_INTF_TO_IMPL(op_ctx);
     
-    if (operation_ctx_impl->msg_ctx_map)
+    if (op_ctx_impl->msg_ctx_map)
     {
-        return axis2_hash_get(operation_ctx_impl->msg_ctx_map, message_id, AXIS2_HASH_KEY_STRING); 
+        return axis2_hash_get(op_ctx_impl->msg_ctx_map, message_id, AXIS2_HASH_KEY_STRING); 
     }
     
     return NULL;
@@ -321,47 +321,47 @@
  * are associated with the MEP has arrived and MEP is complete.
  *
  */
-axis2_bool_t AXIS2_CALL axis2_operation_ctx_get_is_complete(struct axis2_operation_ctx *operation_ctx, 
+axis2_bool_t AXIS2_CALL axis2_op_ctx_get_is_complete(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env) 
 {
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, AXIS2_FAILURE);
-    return AXIS2_INTF_TO_IMPL(operation_ctx)->is_complete;
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, AXIS2_FAILURE);
+    return AXIS2_INTF_TO_IMPL(op_ctx)->is_complete;
 }
 
-axis2_status_t AXIS2_CALL axis2_operation_ctx_set_complete(struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_set_complete(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env, 
     axis2_bool_t is_complete) 
 {
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, AXIS2_FAILURE);
-    AXIS2_INTF_TO_IMPL(operation_ctx)->is_complete = is_complete;
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, AXIS2_FAILURE);
+    AXIS2_INTF_TO_IMPL(op_ctx)->is_complete = is_complete;
     return AXIS2_SUCCESS;
 }
 
 /**
- * Removes the pointers to this <code>operation_ctx</code> in the
- * <code>axis2_conf_ctx</code>'s operation_ctxaxis2_hash_t *so that this
- * <code>operation_ctx</code> will eventually get garbage collected
+ * Removes the pointers to this <code>op_ctx</code> in the
+ * <code>axis2_conf_ctx</code>'s op_ctxaxis2_hash_t *so that this
+ * <code>op_ctx</code> will eventually get garbage collected
  * along with the <code>axis2_msg_ctx_t *</code>'s it contains. Note that if
- * the caller wants to make sure its safe to clean up this operation_ctx
+ * the caller wants to make sure its safe to clean up this op_ctx
  * he should call is_complete() first. However, in cases like IN_OPTIONAL_OUT
  * and OUT_OPTIONAL_IN, it is possibe this will get called without the MEP
  * being complete due to the optional nature of the MEP.
  */
-axis2_status_t AXIS2_CALL axis2_operation_ctx_cleanup(struct axis2_operation_ctx *operation_ctx, 
+axis2_status_t AXIS2_CALL axis2_op_ctx_cleanup(struct axis2_op_ctx *op_ctx, 
     axis2_env_t **env) 
 {
-    axis2_operation_ctx_impl_t *operation_ctx_impl = NULL;
+    axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     axis2_hash_index_t *hi = NULL;
     void *ctx = NULL;
     
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, AXIS2_FAILURE);
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, AXIS2_FAILURE);
     
-    operation_ctx_impl = AXIS2_INTF_TO_IMPL(operation_ctx);
+    op_ctx_impl = AXIS2_INTF_TO_IMPL(op_ctx);
 
-    if (!(operation_ctx_impl->msg_ctx_map))
+    if (!(op_ctx_impl->msg_ctx_map))
         return AXIS2_SUCCESS;
     
-    for (hi = axis2_hash_first (operation_ctx_impl->msg_ctx_map, env);
+    for (hi = axis2_hash_first (op_ctx_impl->msg_ctx_map, env);
              hi; hi = axis2_hash_next (env, hi))
     {
         axis2_hash_this (hi, NULL, NULL, &ctx);
@@ -371,7 +371,7 @@
             /*axis2_char_t *message_id = AXIS2_MSG_CTX_GET_MSG_ID(msg_ctx, env);*/
             /*if (message_id)
             {
-                AXIS2_HASH_SET(operation_ctx_impl->msg_ctx_map, env, message_id, AXIS2_HASH_KEY_STRING, NULL);
+                AXIS2_HASH_SET(op_ctx_impl->msg_ctx_map, env, message_id, AXIS2_HASH_KEY_STRING, NULL);
                 return AXIS2_MSG_CTX_FREE(msg_ctx, env);
             }*/
         }
@@ -380,37 +380,37 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_status_t AXIS2_CALL axis2_operation_ctx_set_parent(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env, struct axis2_svc_ctx* svc_ctx) 
+axis2_status_t AXIS2_CALL axis2_op_ctx_set_parent(struct axis2_op_ctx *op_ctx, axis2_env_t **env, struct axis2_svc_ctx* svc_ctx) 
 {
-    axis2_operation_ctx_impl_t *operation_ctx_impl = NULL;
+    axis2_op_ctx_impl_t *op_ctx_impl = NULL;
     axis2_hash_index_t *hi = NULL;
     axis2_msg_ctx_t *ctx = NULL;
     
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, AXIS2_FAILURE);
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, AXIS2_FAILURE);
     
-    operation_ctx_impl = AXIS2_INTF_TO_IMPL(operation_ctx);
+    op_ctx_impl = AXIS2_INTF_TO_IMPL(op_ctx);
     
     if (svc_ctx)
     {
-        operation_ctx_impl->parent = svc_ctx;
+        op_ctx_impl->parent = svc_ctx;
     }
     
-    if (operation_ctx_impl->parent) /* that is if there is a service context associated */
+    if (op_ctx_impl->parent) /* that is if there is a service context associated */
     {
         /*axis2_conf_ctx_t *conf_ctx = NULL;
-        conf_ctx = AXIS2_SVC_CTX_GET_CONF_CTX(operation_ctx_impl->parent, env);
+        conf_ctx = AXIS2_SVC_CTX_GET_CONF_CTX(op_ctx_impl->parent, env);
         if (conf_ctx)
         {
-            operation_ctx_impl->operation_ctx_map = AXIS2_CONF_CTX_GET_OPERATION_CTX_MAP(conf_ctx, env);
+            op_ctx_impl->op_ctx_map = AXIS2_CONF_CTX_GET_OPERATION_CTX_MAP(conf_ctx, env);
         }
-        operation_ctx_impl->svc_qname = AXIS2_SVC_GET_QNAME(operation_ctx_impl->parent, env);*/
+        op_ctx_impl->svc_qname = AXIS2_SVC_GET_QNAME(op_ctx_impl->parent, env);*/
     }
     
     return AXIS2_SUCCESS;
 }
 
-axis2_hash_t* AXIS2_CALL axis2_operation_ctx_get_msg_ctx_map(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env) 
+axis2_hash_t* AXIS2_CALL axis2_op_ctx_get_msg_ctx_map(struct axis2_op_ctx *op_ctx, axis2_env_t **env) 
 {
-    AXIS2_FUNC_PARAM_CHECK(operation_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(operation_ctx)->msg_ctx_map;
+    AXIS2_FUNC_PARAM_CHECK(op_ctx, env, NULL);
+    return AXIS2_INTF_TO_IMPL(op_ctx)->msg_ctx_map;
 }

Modified: webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c Mon Dec 12 22:23:36 2005
@@ -24,7 +24,7 @@
     axis2_svc_ctx_t svc_ctx;
     /** base context struct */
     axis2_ctx_t *base;
-    /** parent of operation context is a service context instance */
+    /** parent of op context is a service context instance */
     struct axis2_svc_grp_ctx *parent;
     /** service associated with this service context */
     axis2_svc_t *svc;
@@ -52,7 +52,7 @@
                                             axis2_env_t **env);
 struct axis2_conf_ctx* AXIS2_CALL axis2_svc_ctx_get_conf_ctx(struct axis2_svc_ctx *svc_ctx, 
                                             axis2_env_t **env);
-axis2_operation_ctx_t* AXIS2_CALL axis2_svc_ctx_create_operation_ctx(struct axis2_svc_ctx *svc_ctx, 
+axis2_op_ctx_t* AXIS2_CALL axis2_svc_ctx_create_op_ctx(struct axis2_svc_ctx *svc_ctx, 
                                             axis2_env_t **env, axis2_qname_t *qname);
 
 axis2_svc_ctx_t* AXIS2_CALL axis2_svc_ctx_create(axis2_env_t **env, 
@@ -99,7 +99,7 @@
         svc_ctx_impl->parent = svc_grp_ctx;
     }
     
-    /* initialize operations */
+    /* initialize ops */
     
     svc_ctx_impl->svc_ctx.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_svc_ctx_ops_t) );
     if (!svc_ctx_impl->svc_ctx.ops)
@@ -116,7 +116,7 @@
     svc_ctx_impl->svc_ctx.ops->get_svc_id = axis2_svc_ctx_get_svc_id;
     svc_ctx_impl->svc_ctx.ops->get_svc = axis2_svc_ctx_get_svc;
     svc_ctx_impl->svc_ctx.ops->get_conf_ctx = axis2_svc_ctx_get_conf_ctx;
-    svc_ctx_impl->svc_ctx.ops->create_operation_ctx = axis2_svc_ctx_create_operation_ctx;
+    svc_ctx_impl->svc_ctx.ops->create_op_ctx = axis2_svc_ctx_create_op_ctx;
     
     return &(svc_ctx_impl->svc_ctx);
 }
@@ -212,11 +212,11 @@
     return NULL; /*(struct axis2_conf_ctx *) AXIS2_SVC_GRP_CTX_GET_PARENT(AXIS2_INTF_TO_IMPL(svc_ctx)->parent, env);*/
 }
 
-axis2_operation_ctx_t* AXIS2_CALL axis2_svc_ctx_create_operation_ctx(struct axis2_svc_ctx *svc_ctx, 
+axis2_op_ctx_t* AXIS2_CALL axis2_svc_ctx_create_op_ctx(struct axis2_svc_ctx *svc_ctx, 
                                             axis2_env_t **env, axis2_qname_t *qname) 
 {
     axis2_svc_ctx_impl_t *svc_ctx_impl = NULL;
-    axis2_operation_t *operation = NULL;
+    axis2_op_t *op = NULL;
     
     AXIS2_FUNC_PARAM_CHECK(svc_ctx, env, NULL);
     
@@ -224,8 +224,8 @@
     
     if (svc_ctx_impl->svc)
     {
-        /*operation = AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc_ctx_impl->svc, env, qname);
-        return axis2_operation_ctx_create(env, operation, svc_ctx);*/
+        /*op = AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc_ctx_impl->svc, env, qname);
+        return axis2_op_ctx_create(env, op, svc_ctx);*/
     }
     
     return NULL;

Modified: webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c Mon Dec 12 22:23:36 2005
@@ -114,7 +114,7 @@
     
     axis2_svc_grp_ctx_fill_svc_ctx_map((&(svc_grp_ctx_impl->svc_grp_ctx)), env);
     
-    /* initialize operations */
+    /* initialize ops */
     
     svc_grp_ctx_impl->svc_grp_ctx.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_svc_grp_ctx_ops_t) );
     if (!svc_grp_ctx_impl->svc_grp_ctx.ops)
--- webservices/axis2/trunk/c/include/axis2_wsdl_operation.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_operation.h Mon Dec 12 22:23:36 2005
@@ -18,8 +18,8 @@
 #define AXIS2_WSDL_OPERATION_H
 
 /**
  * @file axis2_wsdl_operation.h
  * @brief axis2 wsdl operation interface
  */
 
 #include <axis2.h>
@@ -43,22 +43,22 @@
 #endif
 struct axis2_wsdl_extensible_component;	
 struct axis2_wsdl_fault_ref;    
-typedef struct axis2_wsdl_operation_ops axis2_wsdl_operation_ops_t;
-typedef struct axis2_wsdl_operation axis2_wsdl_operation_t;	
+typedef struct axis2_wsdl_op_ops axis2_wsdl_op_ops_t;
+typedef struct axis2_wsdl_op axis2_wsdl_op_t;	
 	
 
-/** @defgroup axis2_wsdl_operation Wsdl Operation
+/** @defgroup axis2_wsdl_op Wsdl Operation
   * @ingroup axis2_wsdl
   * @{
   */
 
-struct axis2_wsdl_operation_ops
+struct axis2_wsdl_op_ops
 {
 	/** Deallocate memory
      * @return status code
      */
     axis2_status_t (AXIS2_CALL *
-    free) (axis2_wsdl_operation_t *wsdl_operation,
+    free) (axis2_wsdl_op_t *wsdl_op,
             axis2_env_t **env);
         
     /**
@@ -67,7 +67,7 @@
      * @return status code
      */
     axis2_status_t (AXIS2_CALL *
-    set_msg_exchange_pattern) (axis2_wsdl_operation_t *wsdl_operation, 
+    set_msg_exchange_pattern) (axis2_wsdl_op_t *wsdl_op, 
                                 axis2_env_t **env, 
                                 axis2_char_t *msg_exchange_pattern);
   
@@ -76,24 +76,24 @@
      * @return axis2_char_t message exchange pattern
      */
     axis2_char_t *(AXIS2_CALL *
-    get_msg_exchange_pattern) (axis2_wsdl_operation_t *wsdl_operation, 
+    get_msg_exchange_pattern) (axis2_wsdl_op_t *wsdl_op, 
                                 axis2_env_t **env);
 
     /**
-     * Set the wsdl operation name
-     * @param axis2_qname_t* operation name
+     * Set the wsdl op name
+     * @param axis2_qname_t* op name
      */
     axis2_status_t (AXIS2_CALL *
-    set_name) (axis2_wsdl_operation_t *wsdl_operation, 
+    set_name) (axis2_wsdl_op_t *wsdl_op, 
                 axis2_env_t **env,
                 axis2_qname_t *name);
                                         
     /**
-     * Get the name of wsdl operation
-     * @return axis2_qname_t wsdl operation name
+     * Get the name of wsdl op
+     * @return axis2_qname_t wsdl op name
      */
     axis2_qname_t *(AXIS2_CALL *
-    get_name) (axis2_wsdl_operation_t *wsdl_operation,
+    get_name) (axis2_wsdl_op_t *wsdl_op,
                 axis2_env_t **env);
     
 
@@ -103,7 +103,7 @@
      * @return status code
      */
     axis2_status_t (AXIS2_CALL *
-    set_style) (axis2_wsdl_operation_t *wsdl_operation,
+    set_style) (axis2_wsdl_op_t *wsdl_op,
                 axis2_env_t **env,
                 axis2_char_t *style);
     
@@ -112,7 +112,7 @@
      * @return axis2_char_t style
      */
     axis2_char_t *(AXIS2_CALL *
-    get_style) (axis2_wsdl_operation_t *wsdl_operation,
+    get_style) (axis2_wsdl_op_t *wsdl_op,
                 axis2_env_t **env);
     
     
@@ -122,7 +122,7 @@
      * @return
      */
     axis2_linked_list_t * (AXIS2_CALL *
-    get_infaults) (axis2_wsdl_operation_t *wsdl_operation,
+    get_infaults) (axis2_wsdl_op_t *wsdl_op,
                    axis2_env_t **env);
     
     /**
@@ -131,7 +131,7 @@
      * @param infaults
      */
     axis2_status_t (AXIS2_CALL *
-    set_infaults) (axis2_wsdl_operation_t *wsdl_operation,
+    set_infaults) (axis2_wsdl_op_t *wsdl_op,
                     axis2_env_t **env,
                     axis2_linked_list_t *infaults);
     
@@ -141,7 +141,7 @@
      * @return
      */
     struct axis2_wsdl_msg_ref *(AXIS2_CALL *
-    get_input_msg) (axis2_wsdl_operation_t *wsdl_operation,
+    get_input_msg) (axis2_wsdl_op_t *wsdl_op,
                                         axis2_env_t **env);
     
     /**
@@ -150,7 +150,7 @@
      * @param inputMessage
      */
     axis2_status_t (AXIS2_CALL *
-    set_input_msg) (axis2_wsdl_operation_t *wsdl_operation,
+    set_input_msg) (axis2_wsdl_op_t *wsdl_op,
                     axis2_env_t **env,
                     struct axis2_wsdl_msg_ref *input_msg);
     
@@ -160,7 +160,7 @@
      * @return
      */
     axis2_linked_list_t *(AXIS2_CALL *
-    get_outfaults)(axis2_wsdl_operation_t *wsdl_operation,
+    get_outfaults)(axis2_wsdl_op_t *wsdl_op,
                                         axis2_env_t **env);
     
     /**
@@ -169,7 +169,7 @@
      * @param outfaults
      */
     axis2_status_t (AXIS2_CALL *
-    set_outfaults) (axis2_wsdl_operation_t *wsdl_operation,
+    set_outfaults) (axis2_wsdl_op_t *wsdl_op,
                                         axis2_env_t **env,
                                         axis2_linked_list_t *outfaults);
     
@@ -179,7 +179,7 @@
      * @return
      */
     struct axis2_wsdl_msg_ref *(AXIS2_CALL *
-    get_output_msg) (axis2_wsdl_operation_t *wsdl_operation,
+    get_output_msg) (axis2_wsdl_op_t *wsdl_op,
                                         axis2_env_t **env);
     
     /**
@@ -188,7 +188,7 @@
      * @param outputMessage
      */
     axis2_status_t (AXIS2_CALL *
-    set_output_msg) (axis2_wsdl_operation_t *wsdl_operation,
+    set_output_msg) (axis2_wsdl_op_t *wsdl_op,
                         axis2_env_t **env,
                         struct axis2_wsdl_msg_ref *output_msg);
     
@@ -198,7 +198,7 @@
      * @return
      */
     axis2_bool_t (AXIS2_CALL *
-    is_safe) (axis2_wsdl_operation_t *wsdl_operation,
+    is_safe) (axis2_wsdl_op_t *wsdl_op,
                 axis2_env_t **env);
     
     /**
@@ -207,7 +207,7 @@
      * @param safe
      */
     axis2_status_t (AXIS2_CALL *
-    set_safety) (axis2_wsdl_operation_t *wsdl_operation,
+    set_safety) (axis2_wsdl_op_t *wsdl_op,
                     axis2_env_t **env,
                     axis2_bool_t safe);
     
@@ -217,7 +217,7 @@
      * @return
      */
     axis2_char_t *(AXIS2_CALL *
-    get_target_namespace) (axis2_wsdl_operation_t *wsdl_operation,
+    get_target_namespace) (axis2_wsdl_op_t *wsdl_op,
                             axis2_env_t **env);
     
     /**
@@ -226,7 +226,7 @@
      * @param inFault
      */
     axis2_status_t (AXIS2_CALL *
-    add_infault) (axis2_wsdl_operation_t *wsdl_operation,
+    add_infault) (axis2_wsdl_op_t *wsdl_op,
                     axis2_env_t **env,
                     struct axis2_wsdl_fault_ref *infault);
     
@@ -236,81 +236,81 @@
      * @param outFault
      */
     axis2_status_t (AXIS2_CALL *
-    add_outfault) (axis2_wsdl_operation_t *wsdl_operation,
+    add_outfault) (axis2_wsdl_op_t *wsdl_op,
                     axis2_env_t **env,
                     struct axis2_wsdl_fault_ref *outfault);
 };
 
-struct axis2_wsdl_operation
+struct axis2_wsdl_op
 {
-	axis2_wsdl_operation_ops_t *ops;
+	axis2_wsdl_op_ops_t *ops;
     struct axis2_wsdl_extensible_component *extensible_component;
 };
 
-AXIS2_DECLARE(axis2_wsdl_operation_t *) axis2_wsdl_operation_create (
+AXIS2_DECLARE(axis2_wsdl_op_t *) axis2_wsdl_op_create (
                                                             axis2_env_t **env);
 
 /**************************** Start of function macros ************************/
 
-#define AXIS2_WSDL_OPERATION_FREE(wsdl_operation, env) \
-		((wsdl_operation->ops)->free (wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_FREE(wsdl_op, env) \
+		((wsdl_op->ops)->free (wsdl_op, env))
 	
-#define AXIS2_WSDL_OPERATION_GET_MSG_EXCHANGE_PATTERN(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_msg_exchange_pattern(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_GET_MSG_EXCHANGE_PATTERN(wsdl_op, env) \
+		((wsdl_op->ops)->get_msg_exchange_pattern(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_MSG_EXCHANGE_PATTERN(wsdl_operation, env, pattern) \
-		((wsdl_operation->ops)->set_msg_exchange_pattern(wsdl_operation, env, pattern))
+#define AXIS2_WSDL_OPERATION_SET_MSG_EXCHANGE_PATTERN(wsdl_op, env, pattern) \
+		((wsdl_op->ops)->set_msg_exchange_pattern(wsdl_op, env, pattern))
 		
-#define AXIS2_WSDL_OPERATION_GET_NAME(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_name(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_GET_NAME(wsdl_op, env) \
+		((wsdl_op->ops)->get_name(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_NAME(wsdl_operation, env, name) \
-		((wsdl_operation->ops)->set_name(wsdl_operation, env, name))
+#define AXIS2_WSDL_OPERATION_SET_NAME(wsdl_op, env, name) \
+		((wsdl_op->ops)->set_name(wsdl_op, env, name))
 		
-#define AXIS2_WSDL_OPERATION_SET_STYLE(wsdl_operation, env, style) \
-		((wsdl_operation->ops)->set_style(wsdl_operation, env, style))
+#define AXIS2_WSDL_OPERATION_SET_STYLE(wsdl_op, env, style) \
+		((wsdl_op->ops)->set_style(wsdl_op, env, style))
 		
-#define AXIS2_WSDL_OPERATION_GET_STYLE(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_style(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_GET_STYLE(wsdl_op, env) \
+		((wsdl_op->ops)->get_style(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_GET_INFAULTS(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_infaults(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_GET_INFAULTS(wsdl_op, env) \
+		((wsdl_op->ops)->get_infaults(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_INFAULTS(wsdl_operation, env, infaults) \
-		((wsdl_operation->ops)->set_infaults(wsdl_operation, env, infaults))
+#define AXIS2_WSDL_OPERATION_SET_INFAULTS(wsdl_op, env, infaults) \
+		((wsdl_op->ops)->set_infaults(wsdl_op, env, infaults))
 
-#define AXIS2_WSDL_OPERATION_GET_INPUT_MSG(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_input_msg(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_GET_INPUT_MSG(wsdl_op, env) \
+		((wsdl_op->ops)->get_input_msg(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_INPUT_MSG(wsdl_operation, env, input_msg) \
-		((wsdl_operation->ops)->set_input_msg(wsdl_operation, env, input_msg))		
+#define AXIS2_WSDL_OPERATION_SET_INPUT_MSG(wsdl_op, env, input_msg) \
+		((wsdl_op->ops)->set_input_msg(wsdl_op, env, input_msg))		
 
-#define AXIS2_WSDL_OPERATION_GET_OUTFAULTS(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_outfaults(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_GET_OUTFAULTS(wsdl_op, env) \
+		((wsdl_op->ops)->get_outfaults(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_OUTFAULTS(wsdl_operation, env, outfaults) \
-		((wsdl_operation->ops)->set_outfaults(wsdl_operation, env, outfaults))
+#define AXIS2_WSDL_OPERATION_SET_OUTFAULTS(wsdl_op, env, outfaults) \
+		((wsdl_op->ops)->set_outfaults(wsdl_op, env, outfaults))
 
-#define AXIS2_WSDL_OPERATION_GET_OUTPUT_MSG(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_output_msg(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_GET_OUTPUT_MSG(wsdl_op, env) \
+		((wsdl_op->ops)->get_output_msg(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_OUTPUT_MSG(wsdl_operation, env, output_msg) \
-		((wsdl_operation->ops)->set_output_msg(wsdl_operation, env, output_msg))
+#define AXIS2_WSDL_OPERATION_SET_OUTPUT_MSG(wsdl_op, env, output_msg) \
+		((wsdl_op->ops)->set_output_msg(wsdl_op, env, output_msg))
 
-#define AXIS2_WSDL_OPERATION_IS_SAFE(wsdl_operation, env) \
-		((wsdl_operation->ops)->is_safe(wsdl_operation, env))
+#define AXIS2_WSDL_OPERATION_IS_SAFE(wsdl_op, env) \
+		((wsdl_op->ops)->is_safe(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_SAFETY(wsdl_operation, env, safe) \
-		((wsdl_operation->ops)->set_safety(wsdl_operation, env, safe))
+#define AXIS2_WSDL_OPERATION_SET_SAFETY(wsdl_op, env, safe) \
+		((wsdl_op->ops)->set_safety(wsdl_op, env, safe))
         
-#define AXIS2_WSDL_OPERATION_GET_TARGET_NAMESPACE(wsdl_operation, env) \
-		((wsdl_operation->ops)->get_target_namespace(wsdl_operation, env))        
+#define AXIS2_WSDL_OPERATION_GET_TARGET_NAMESPACE(wsdl_op, env) \
+		((wsdl_op->ops)->get_target_namespace(wsdl_op, env))        
 
-#define AXIS2_WSDL_OPERATION_ADD_INFAULT(wsdl_operation, env, infault) \
-		((wsdl_operation->ops)->add_infault(wsdl_operation, env, infault))
+#define AXIS2_WSDL_OPERATION_ADD_INFAULT(wsdl_op, env, infault) \
+		((wsdl_op->ops)->add_infault(wsdl_op, env, infault))
 		
-#define AXIS2_WSDL_OPERATION_ADD_OUTFAULT(wsdl_operation, env, outfault) \
-		((wsdl_operation->ops)->add_outfault(wsdl_operation, env, outfault))
+#define AXIS2_WSDL_OPERATION_ADD_OUTFAULT(wsdl_op, env, outfault) \
+		((wsdl_op->ops)->add_outfault(wsdl_op, env, outfault))
 
 /**************************** End of function macros **************************/
 
@@ -18,8 +18,8 @@
 
 /**
- * @file axis2_wsdl_operation.h
- * @brief axis2 wsdl operation interface
+ * @file axis2_wsdl_op.h
+ * @brief axis2 wsdl op interface
  */
 

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_property.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_property.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_soap_operation.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_soap_operation.h Mon Dec 12 22:23:36 2005
@@ -18,8 +18,8 @@
 #define AXIS2_WSDL_SOAP_OPERATION_H
 
 /**
  * @file axis2_wsdl_soap_operation.h
  * @brief Axis2 Wsdl soap operation interface
  */
 
 #include <axis2.h>
@@ -36,42 +36,42 @@
 {
 #endif
 
-typedef struct axis2_wsdl_soap_operation axis2_wsdl_soap_operation_t;
-typedef struct axis2_wsdl_soap_operation_ops axis2_wsdl_soap_operation_ops_t;
+typedef struct axis2_wsdl_soap_op axis2_wsdl_soap_op_t;
+typedef struct axis2_wsdl_soap_op_ops axis2_wsdl_soap_op_ops_t;
 
 /** @defgroup axis2_wsdl_soap_operation Wsdl Extensible Element
  * @ingroup axis2_wsdl
  * @{
  */
 
 /** 
  * @brief Wsdl Extensible Element operations struct
  * Encapsulator struct for operations of axis2_wsdl_soap_operation
  */
-AXIS2_DECLARE_DATA struct axis2_wsdl_soap_operation_ops
+AXIS2_DECLARE_DATA struct axis2_wsdl_soap_op_ops
 {
 	/** De-allocate memory
   	 * @return status code
   	 */
 	axis2_status_t (AXIS2_CALL *free)(
-                    axis2_wsdl_soap_operation_t *wsdl_soap_operation,
+                    axis2_wsdl_soap_op_t *wsdl_soap_op,
 			        axis2_env_t **env);
 
     axis2_char_t *(AXIS2_CALL *
-    get_style) (axis2_wsdl_soap_operation_t *soap_operation,
+    get_style) (axis2_wsdl_soap_op_t *soap_op,
                                         axis2_env_t **env);
         
     axis2_status_t (AXIS2_CALL *
-    set_style) (axis2_wsdl_soap_operation_t *soap_operation,
+    set_style) (axis2_wsdl_soap_op_t *soap_op,
                                         axis2_env_t **env,
                                         axis2_char_t *style);
     
     axis2_char_t * (AXIS2_CALL *
-    get_soap_action) (axis2_wsdl_soap_operation_t *soap_operation,
+    get_soap_action) (axis2_wsdl_soap_op_t *soap_op,
                                         axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_soap_action) (axis2_wsdl_soap_operation_t *soap_operation,
+    set_soap_action) (axis2_wsdl_soap_op_t *soap_op,
                                         axis2_env_t **env,
                                         axis2_char_t *soap_action);
 };
@@ -80,9 +80,9 @@
  * @brief Wsdl container struct
  *	Property for params  
  */  
-AXIS2_DECLARE_DATA struct axis2_wsdl_soap_operation
+AXIS2_DECLARE_DATA struct axis2_wsdl_soap_op
 {
-	axis2_wsdl_soap_operation_ops_t *ops;
+	axis2_wsdl_soap_op_ops_t *ops;
     axis2_wsdl_extensible_element_t *extensible_element;
 };
 
@@ -90,16 +90,16 @@
  * Creates wsdl property struct
  * @return pointer to newly created wsdl property
  */
-AXIS2_DECLARE(axis2_wsdl_soap_operation_t *) 
-axis2_wsdl_soap_operation_create (axis2_env_t **env);
+AXIS2_DECLARE(axis2_wsdl_soap_op_t *) 
+axis2_wsdl_soap_op_create (axis2_env_t **env);
 
 /**
  * Creates wsdl property struct
  * @param type 
  * @return pointer to newly created wsdl property
  */
-AXIS2_DECLARE(axis2_wsdl_soap_operation_t *) 
-axis2_wsdl_soap_operation_create_with_type (axis2_env_t **env, axis2_qname_t *type);
+AXIS2_DECLARE(axis2_wsdl_soap_op_t *) 
+axis2_wsdl_soap_op_create_with_type (axis2_env_t **env, axis2_qname_t *type);
 
 /*************************** Function macros **********************************/
 
@@ -18,8 +18,8 @@
 
 /**
- * @file axis2_wsdl_soap_operation.h
- * @brief Axis2 Wsdl soap operation interface
+ * @file axis2_wsdl_soap_op.h
+ * @brief Axis2 Wsdl soap op interface
  */
 
@@ -36,42 +36,42 @@
 
-/** @defgroup axis2_wsdl_soap_operation Wsdl Extensible Element
+/** @defgroup axis2_wsdl_soap_op Wsdl Extensible Element
  * @ingroup axis2_wsdl
  * @{
@@ -36,42 +36,42 @@
 
 /** 
- * @brief Wsdl Extensible Element operations struct
- * Encapsulator struct for operations of axis2_wsdl_soap_operation
+ * @brief Wsdl Extensible Element ops struct
+ * Encapsulator struct for ops of axis2_wsdl_soap_op
  */

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_svc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_svc.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c Mon Dec 12 22:23:36 2005
@@ -15,7 +15,7 @@
  */
  
 #include <axis2_msg_ctx.h>
-#include <axis2_operation.h>
+#include <axis2_op.h>
 #include <axis2_svc.h>
 #include <axis2_svc_grp.h>
 #include <axis2_engine_config.h>
@@ -32,8 +32,8 @@
 	axis2_msg_ctx_t msg_ctx;
     /** base context struct */
     axis2_ctx_t *base;
-    /** parent of message context is an operation context instance */
-    struct axis2_operation_ctx *parent;
+    /** parent of message context is an op context instance */
+    struct axis2_op_ctx *parent;
     /** process fault enabled? */    
     axis2_bool_t process_fault;
     /**
@@ -44,15 +44,15 @@
      */
     axis2_msg_info_headers_t *msg_info_headers;
 
-    struct axis2_operation_ctx *operation_ctx;
+    struct axis2_op_ctx *op_ctx;
     struct axis2_svc_ctx *svc_ctx;
     struct axis2_svc_grp_ctx *svc_grp_ctx;
     struct axis2_conf_ctx *conf_ctx;
     /** session context */
     struct axis2_session_ctx *session_ctx;
     
-    /** operation */
-    axis2_operation_t *operation;
+    /** op */
+    axis2_op_t *op;
     /** service */
     axis2_svc_t *svc;
     /** service group */
@@ -104,8 +104,8 @@
     axis2_char_t *svc_grp_id;
     /** service description qname */
     axis2_qname_t *svc_qname;
-    /** operation qname */
-    axis2_qname_t *operation_qname;
+    /** op qname */
+    axis2_qname_t *op_qname;
 };
 
 #define AXIS2_INTF_TO_IMPL(msg_ctx) ((axis2_msg_ctx_impl_t *) msg_ctx)
@@ -115,13 +115,13 @@
 struct axis2_ctx* AXIS2_CALL
 axis2_msg_ctx_get_base(struct axis2_msg_ctx *msg_ctx, 
                         axis2_env_t **env);
-struct axis2_operation_ctx* AXIS2_CALL
+struct axis2_op_ctx* AXIS2_CALL
 axis2_msg_ctx_get_parent(struct axis2_msg_ctx *msg_ctx, 
                             axis2_env_t **env);
 axis2_status_t AXIS2_CALL
 axis2_msg_ctx_set_parent(struct axis2_msg_ctx *msg_ctx, 
                             axis2_env_t **env, 
-                            struct axis2_operation_ctx *parent);
+                            struct axis2_op_ctx *parent);
 
 axis2_status_t AXIS2_CALL
 axis2_msg_ctx_free (axis2_msg_ctx_t *msg_ctx,
@@ -270,14 +270,14 @@
 axis2_msg_ctx_set_transport_out_desc(struct axis2_msg_ctx *msg_ctx, 
                                         axis2_env_t **env, 
                                         struct axis2_transport_out_desc *transport_out_desc); 
-struct axis2_operation_ctx* AXIS2_CALL
-axis2_msg_ctx_get_operation_ctx(struct axis2_msg_ctx *msg_ctx, 
+struct axis2_op_ctx* AXIS2_CALL
+axis2_msg_ctx_get_op_ctx(struct axis2_msg_ctx *msg_ctx, 
                                     axis2_env_t **env);
 
 axis2_status_t AXIS2_CALL
-axis2_msg_ctx_set_operation_ctx(struct axis2_msg_ctx *msg_ctx, 
+axis2_msg_ctx_set_op_ctx(struct axis2_msg_ctx *msg_ctx, 
                                 axis2_env_t **env, 
-                                struct axis2_operation_ctx * operation_ctx);
+                                struct axis2_op_ctx * op_ctx);
 axis2_bool_t AXIS2_CALL
 axis2_msg_ctx_get_output_written(struct axis2_msg_ctx *msg_ctx, 
                                     axis2_env_t **env);
@@ -370,13 +370,13 @@
 axis2_msg_ctx_set_svc_grp_ctx(struct axis2_msg_ctx *msg_ctx, 
                                 axis2_env_t **env, 
                                 struct axis2_svc_grp_ctx *svc_grp_ctx);
-axis2_operation_t* AXIS2_CALL
-axis2_msg_ctx_get_operation(struct axis2_msg_ctx *msg_ctx, 
+axis2_op_t* AXIS2_CALL
+axis2_msg_ctx_get_op(struct axis2_msg_ctx *msg_ctx, 
                                 axis2_env_t **env);
 axis2_status_t AXIS2_CALL
-axis2_msg_ctx_set_operation(struct axis2_msg_ctx *msg_ctx, 
+axis2_msg_ctx_set_op(struct axis2_msg_ctx *msg_ctx, 
                             axis2_env_t **env, 
-                            axis2_operation_t *operation);
+                            axis2_op_t *op);
 axis2_svc_t* AXIS2_CALL
 axis2_msg_ctx_get_svc(struct axis2_msg_ctx *msg_ctx, 
                         axis2_env_t **env);
@@ -405,7 +405,7 @@
 
 axis2_svc_t* AXIS2_CALL axis2_msg_ctx_find_svc(axis2_msg_ctx_t *msg_ctx, 
                 axis2_env_t **env);
-axis2_operation_t* AXIS2_CALL axis2_msg_ctx_find_operation(axis2_msg_ctx_t *msg_ctx,
+axis2_op_t* AXIS2_CALL axis2_msg_ctx_find_op(axis2_msg_ctx_t *msg_ctx,
                             axis2_env_t **env,
                             axis2_svc_t *svc);
 
@@ -434,12 +434,12 @@
     msg_ctx_impl->base = NULL;
     msg_ctx_impl->process_fault = AXIS2_FALSE;
     /*msg_ctx_impl->msg_info_headers = NULL;*/
-    msg_ctx_impl->operation_ctx = NULL;
+    msg_ctx_impl->op_ctx = NULL;
     msg_ctx_impl->svc_ctx = NULL;
     msg_ctx_impl->svc_grp_ctx = NULL;
     msg_ctx_impl->conf_ctx = NULL;
     msg_ctx_impl->session_ctx = NULL;
-    msg_ctx_impl->operation = NULL;
+    msg_ctx_impl->op = NULL;
     msg_ctx_impl->svc = NULL;
     msg_ctx_impl->svc_grp = NULL;    
     /*msg_ctx_impl->transport_in_desc = NULL;
@@ -465,7 +465,7 @@
     msg_ctx_impl->transport_out_desc_qname = NULL;
     msg_ctx_impl->svc_grp_id = NULL;
     msg_ctx_impl->svc_qname = NULL;
-    msg_ctx_impl->operation_qname = NULL;
+    msg_ctx_impl->op_qname = NULL;
     
     msg_ctx_impl->base = axis2_ctx_create(env);
     if (!(msg_ctx_impl->base))
@@ -507,7 +507,7 @@
         return NULL;
     }*/
     
-    /* initialize operations */
+    /* initialize ops */
     msg_ctx_impl->msg_ctx.ops  = AXIS2_MALLOC( (*env)->allocator, sizeof(axis2_msg_ctx_ops_t) );
     if (!msg_ctx_impl->msg_ctx.ops)
     {
@@ -577,8 +577,8 @@
     msg_ctx_impl->msg_ctx.ops->get_transport_out_desc = axis2_msg_ctx_get_transport_out_desc;
     msg_ctx_impl->msg_ctx.ops->set_transport_in_desc = axis2_msg_ctx_set_transport_in_desc;
     msg_ctx_impl->msg_ctx.ops->set_transport_out_desc = axis2_msg_ctx_set_transport_out_desc;
-    msg_ctx_impl->msg_ctx.ops->get_operation_ctx = axis2_msg_ctx_get_operation_ctx;
-    msg_ctx_impl->msg_ctx.ops->set_operation_ctx = axis2_msg_ctx_set_operation_ctx;
+    msg_ctx_impl->msg_ctx.ops->get_op_ctx = axis2_msg_ctx_get_op_ctx;
+    msg_ctx_impl->msg_ctx.ops->set_op_ctx = axis2_msg_ctx_set_op_ctx;
     msg_ctx_impl->msg_ctx.ops->get_output_written = axis2_msg_ctx_get_output_written;
     msg_ctx_impl->msg_ctx.ops->set_output_written = axis2_msg_ctx_set_output_written;
     msg_ctx_impl->msg_ctx.ops->get_svc_ctx_id = axis2_msg_ctx_get_svc_ctx_id;
@@ -605,8 +605,8 @@
     msg_ctx_impl->msg_ctx.ops->get_is_soap_11 = axis2_msg_ctx_get_is_soap_11;
     msg_ctx_impl->msg_ctx.ops->get_svc_grp_ctx = axis2_msg_ctx_get_svc_grp_ctx;
     msg_ctx_impl->msg_ctx.ops->set_svc_grp_ctx = axis2_msg_ctx_set_svc_grp_ctx;
-    msg_ctx_impl->msg_ctx.ops->get_operation = axis2_msg_ctx_get_operation;
-    msg_ctx_impl->msg_ctx.ops->set_operation = axis2_msg_ctx_set_operation;
+    msg_ctx_impl->msg_ctx.ops->get_op = axis2_msg_ctx_get_op;
+    msg_ctx_impl->msg_ctx.ops->set_op = axis2_msg_ctx_set_op;
     msg_ctx_impl->msg_ctx.ops->get_svc = axis2_msg_ctx_get_svc;
     msg_ctx_impl->msg_ctx.ops->set_svc = axis2_msg_ctx_set_svc;
     msg_ctx_impl->msg_ctx.ops->get_svc_grp = axis2_msg_ctx_get_svc_grp;
@@ -615,7 +615,7 @@
     msg_ctx_impl->msg_ctx.ops->set_svc_grp_ctx_id = axis2_msg_ctx_set_svc_grp_ctx_id;
     msg_ctx_impl->msg_ctx.ops->is_paused = axis2_msg_ctx_is_paused;
     msg_ctx_impl->msg_ctx.ops->find_svc = axis2_msg_ctx_find_svc;
-    msg_ctx_impl->msg_ctx.ops->find_operation = axis2_msg_ctx_find_operation;
+    msg_ctx_impl->msg_ctx.ops->find_op = axis2_msg_ctx_find_op;
     
     return &(msg_ctx_impl->msg_ctx);
 }
@@ -629,7 +629,7 @@
 }
 
 
-struct axis2_operation_ctx * AXIS2_CALL axis2_msg_ctx_get_parent(struct axis2_msg_ctx *msg_ctx, 
+struct axis2_op_ctx * AXIS2_CALL axis2_msg_ctx_get_parent(struct axis2_msg_ctx *msg_ctx, 
                                             axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(msg_ctx, env, NULL);
@@ -640,7 +640,7 @@
  * @param context
  */
 axis2_status_t AXIS2_CALL axis2_msg_ctx_set_parent(struct axis2_msg_ctx *msg_ctx, 
-                                            axis2_env_t **env, struct axis2_operation_ctx *parent) 
+                                            axis2_env_t **env, struct axis2_op_ctx *parent) 
 {
     AXIS2_FUNC_PARAM_CHECK(msg_ctx, env, AXIS2_FAILURE);
     
@@ -756,10 +756,10 @@
         /*msg_ctx_impl->svc = AXIS2_ENGINE_CONFIG_GET_SVC(engine_config, env, AXIS2_QNAME_GET_LOCALPART(msg_ctx_impl->svc_qname, env));*/
     }
     
-    if (msg_ctx_impl->operation_qname)
+    if (msg_ctx_impl->op_qname)
     {
         /*if (msg_ctx_impl->svc)
-            msg_ctx_impl->operation = AXIS2_SVC_GET_OPERATION_WITH_QNAME(msg_ctx_impl->svc, env, msg_ctx_impl->operation_qname);*/
+            msg_ctx_impl->op = AXIS2_SVC_GET_OPERATION_WITH_QNAME(msg_ctx_impl->svc, env, msg_ctx_impl->op_qname);*/
     }
     
     return AXIS2_SUCCESS;
@@ -1232,18 +1232,18 @@
     return AXIS2_SUCCESS;
 }
 
-struct axis2_operation_ctx * AXIS2_CALL axis2_msg_ctx_get_operation_ctx(struct axis2_msg_ctx *msg_ctx, 
+struct axis2_op_ctx * AXIS2_CALL axis2_msg_ctx_get_op_ctx(struct axis2_msg_ctx *msg_ctx, 
                                             axis2_env_t **env)
 {
     AXIS2_FUNC_PARAM_CHECK(msg_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(msg_ctx)->operation_ctx;
+    return AXIS2_INTF_TO_IMPL(msg_ctx)->op_ctx;
 }
 
 /**
  * @param context
  */
-axis2_status_t AXIS2_CALL axis2_msg_ctx_set_operation_ctx(struct axis2_msg_ctx *msg_ctx, 
-                                            axis2_env_t **env, struct axis2_operation_ctx * operation_ctx) 
+axis2_status_t AXIS2_CALL axis2_msg_ctx_set_op_ctx(struct axis2_msg_ctx *msg_ctx, 
+                                            axis2_env_t **env, struct axis2_op_ctx * op_ctx) 
 {
     axis2_msg_ctx_impl_t *msg_ctx_impl = NULL;
     
@@ -1251,19 +1251,19 @@
     
     msg_ctx_impl = AXIS2_INTF_TO_IMPL(msg_ctx);
     
-    if (operation_ctx)
+    if (op_ctx)
     {
-        msg_ctx_impl->operation_ctx = operation_ctx;
+        msg_ctx_impl->op_ctx = op_ctx;
         
         if (msg_ctx_impl->svc_ctx)
         {
-            /*if (!(AXIS2_OPERATION_CTX_GET_PARENT(msg_ctx_impl->operation_ctx, env)))
+            /*if (!(AXIS2_OPERATION_CTX_GET_PARENT(msg_ctx_impl->op_ctx, env)))
             {
-                AXIS2_OPERATION_CTX_SET_PARENT(msg_ctx_impl->operation_ctx, env, msg_ctx_impl->svc_ctx);
+                AXIS2_OPERATION_CTX_SET_PARENT(msg_ctx_impl->op_ctx, env, msg_ctx_impl->svc_ctx);
             }*/
         }
-        axis2_msg_ctx_set_parent(msg_ctx, env, operation_ctx);
-        /*axis2_msg_ctx_set_operation(msg_ctx, env, AXIS2_OPERATION_CTX_GET_OPRATION(operation_ctx, env));    */
+        axis2_msg_ctx_set_parent(msg_ctx, env, op_ctx);
+        /*axis2_msg_ctx_set_op(msg_ctx, env, AXIS2_OPERATION_CTX_GET_OPRATION(op_ctx, env));    */
     }
     return AXIS2_SUCCESS;
 }
@@ -1382,10 +1382,10 @@
     {
         msg_ctx_impl->svc_ctx = svc_ctx;
         
-        if(msg_ctx_impl->operation_ctx)
+        if(msg_ctx_impl->op_ctx)
         {
-            /*if (!AXIS2_OPERATION_CTX_GET_PARENT(msg_ctx_impl->operation_ctx, env))
-                AXIS2_OPERATION_CTX_SET_PARENT(msg_ctx_impl->operation_ctx, env, svc_ctx);*/
+            /*if (!AXIS2_OPERATION_CTX_GET_PARENT(msg_ctx_impl->op_ctx, env))
+                AXIS2_OPERATION_CTX_SET_PARENT(msg_ctx_impl->op_ctx, env, svc_ctx);*/
         }
         /*set_svc(msg_ctx, env, AXIS2_SVC_CTX_GET_SVC(svc_ctx, env);*/
     }
@@ -1414,8 +1414,8 @@
 /**
  * To retrive configuration descriptor parameters , it is posible to AXIS2_CALL axis2_msg_ctx_get paramater specify at
  * any levle via this method , and the preferance is as follows,
  * 1. Search in operation description if its there
  * 2. if the paramter not found or operation_ctx is null will search in
  * _svc
  * 3. If the svc is null or , the paramter does not found will serach in
  * AxisConfiguration
@@ -1433,9 +1433,9 @@
     
     msg_ctx_impl = AXIS2_INTF_TO_IMPL(msg_ctx);
     
-    if (msg_ctx_impl->operation) 
+    if (msg_ctx_impl->op) 
     {
-        /*param = AXIS2_OPERATION_GET_PARAM(msg_ctx_impl->operation, env, key);*/
+        /*param = AXIS2_OPERATION_GET_PARAM(msg_ctx_impl->op, env, key);*/
         if (param)
         {
             return param;
@@ -1473,8 +1473,8 @@
 /**
  * This method is to retrive both module configuration parameters and othere paramerts
  * The searching procedure is as follows;
- * 1. Search in module configurations inside corresponding operation descripton if its three
- * 2. Search in corresponding operation if its there
+ * 1. Search in module configurations inside corresponding op descripton if its three
+ * 2. Search in corresponding op if its there
  * 3. Search in module configurations inside corresponding service description if its there
  * 4. Next search in Corresponding Service description if its there
  * 5. Next sercah in module configurations inside engine_config
@@ -1511,9 +1511,9 @@
     
     qname = axis2_qname_create(env, module_name, NULL, NULL);
     
-    if (msg_ctx_impl->operation)
+    if (msg_ctx_impl->op)
     {
-        /*module_config = AXIS2_OPERATION_GET_MODULE_CONFIG(msg_ctx_impl->operation, env, qname);*/
+        /*module_config = AXIS2_OPERATION_GET_MODULE_CONFIG(msg_ctx_impl->op, env, qname);*/
         AXIS2_QNAME_FREE(qname, env);
         /*if (module_config) 
         {
@@ -1524,7 +1524,7 @@
             } 
             else 
             {
-                param = AXIS2_OPERATION_GET_PARAM(msg_ctx_impl->operation, env, key);
+                param = AXIS2_OPERATION_GET_PARAM(msg_ctx_impl->op, env, key);
                 if (param)
                 {
                     return param;
@@ -1627,7 +1627,7 @@
 
 /**
  * To acess any property AXIS2_CALL axis2_msg_ctx_set at the run time , a handler can add property to wherever he wants
  * to MesageContext , to struct axis2_operation_ctx * , to struct axis2_svc_ctx *and to ConfigurationContext.
  * This method is to retrive those properties NOT paramters
  *
  * @param key        : property Name
@@ -1646,8 +1646,8 @@
     //The context hirachy might not have constructed fully, the check should
     //look for the disconnected grandparents
     // Search in Operation Context
-    if (operation_ctx != null ) {
-        obj = operation_ctxgetProperty(key, persistent);
+    if (op_ctx != null ) {
+        obj = op_ctxgetProperty(key, persistent);
         if(obj !=null){
             return obj;
         }
@@ -1853,22 +1853,22 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_operation_t *AXIS2_CALL axis2_msg_ctx_get_operation(struct axis2_msg_ctx *msg_ctx, 
+axis2_op_t *AXIS2_CALL axis2_msg_ctx_get_op(struct axis2_msg_ctx *msg_ctx, 
                                             axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(msg_ctx, env, NULL);
-    return AXIS2_INTF_TO_IMPL(msg_ctx)->operation;
+    return AXIS2_INTF_TO_IMPL(msg_ctx)->op;
 }
 
-axis2_status_t AXIS2_CALL axis2_msg_ctx_set_operation(struct axis2_msg_ctx *msg_ctx, 
-                                            axis2_env_t **env, axis2_operation_t *operation) 
+axis2_status_t AXIS2_CALL axis2_msg_ctx_set_op(struct axis2_msg_ctx *msg_ctx, 
+                                            axis2_env_t **env, axis2_op_t *op) 
 {
     AXIS2_FUNC_PARAM_CHECK(msg_ctx, env, AXIS2_FAILURE);
     
-    if (operation)
+    if (op)
     {
-        AXIS2_INTF_TO_IMPL(msg_ctx)->operation = operation;
-        AXIS2_INTF_TO_IMPL(msg_ctx)->operation_qname = AXIS2_OPERATION_GET_NAME(operation, env);
+        AXIS2_INTF_TO_IMPL(msg_ctx)->op = op;
+        AXIS2_INTF_TO_IMPL(msg_ctx)->op_qname = AXIS2_OPERATION_GET_NAME(op, env);
     }
     
     return AXIS2_SUCCESS;
@@ -1962,7 +1962,7 @@
 /** TODO: there are many block to be uncommented once external depandancies are resoled,
     that is when thos structs are implemented */
 
 /** find_svc and find_operation methods has to implemented by the dispatchers and
     the function pointers assigined to the ops of message context.
     The following are just dummy implemntations.
 */
@@ -1972,7 +1972,7 @@
     return NULL;
 }
 
-axis2_operation_t* AXIS2_CALL axis2_msg_ctx_find_operation(axis2_msg_ctx_t *msg_ctx,
+axis2_op_t* AXIS2_CALL axis2_msg_ctx_find_op(axis2_msg_ctx_t *msg_ctx,
                             axis2_env_t **env,
                             axis2_svc_t *svc)
 {
@@ -1414,8 +1414,8 @@
  * To retrive configuration descriptor parameters , it is posible to AXIS2_CALL axis2_msg_ctx_get paramater specify at
  * any levle via this method , and the preferance is as follows,
- * 1. Search in operation description if its there
- * 2. if the paramter not found or operation_ctx is null will search in
+ * 1. Search in op description if its there
+ * 2. if the paramter not found or op_ctx is null will search in
  * _svc
  * 3. If the svc is null or , the paramter does not found will serach in
@@ -1627,7 +1627,7 @@
 /**
  * To acess any property AXIS2_CALL axis2_msg_ctx_set at the run time , a handler can add property to wherever he wants
- * to MesageContext , to struct axis2_operation_ctx * , to struct axis2_svc_ctx *and to ConfigurationContext.
+ * to MesageContext , to struct axis2_op_ctx * , to struct axis2_svc_ctx *and to ConfigurationContext.
  * This method is to retrive those properties NOT paramters
  *
@@ -1962,7 +1962,7 @@
     that is when thos structs are implemented */
 
-/** find_svc and find_operation methods has to implemented by the dispatchers and
+/** find_svc and find_op methods has to implemented by the dispatchers and
     the function pointers assigined to the ops of message context.
     The following are just dummy implemntations.

Modified: webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/operation_ctx.c?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================